

A package that simplifies data validation in your pipeline by abstracting the complexity
of Great Expectations away. Easy G.E (_pronounced ee-zee-jee-ee_) is designed for common
use cases (in-memory and file scenarios), enabling you to set up tests in minutes without
having to get acquainted with Great Expectations itself.

to get started simply run
```python
pip install easy-ge # or easy-ge[google] for google backend
```

For more information and detailed instructions, check out the [GitHub
repository](https://github.com/Elsayed91/easy_ge).
